IntoGradientLch

Trait IntoGradientLch 

pub trait IntoGradientLch:
    Sized
    + IntoColor<Lch>
    + FromColor<Lch>
    + Copy {
    // Provided method
    fn build_gradient_lch(self, shades: u16) -> Vec<Self> { ... }
}
Defines a colour that can generate a gradient through Lch.

Should be auto-implemented by having a colour satisfy the trait bounds.

Provided Methods

fn build_gradient_lch(self, shades: u16) -> Vec<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors