IntoGradientOklch

Trait IntoGradientOklch 

pub trait IntoGradientOklch:
    Sized
    + IntoColor<Oklch>
    + FromColor<Oklch>
    + Copy {
    // Provided method
    fn build_gradient_oklch(self, shades: u16) -> Vec<Self> { ... }
}
Defines a colour that can generate a gradient through Oklch. Tends to distort hues… unknown why.

Should be auto-implemented by having a colour satisfy the trait bounds.

Provided Methods

fn build_gradient_oklch(self, shades: u16) -> Vec<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors