Module dither

Module dither 

Various dithering algorithms, including both error propagation and ordered.

For error propagation, existing algorithms are setup as constants. These aren’t directly usable as an effect since they need to be configured with a palette.

As for Bayer, it requires a palette to be initialized with, so it doesn’t face this issue.

Re-exports

pub use error::FLOYD_STEINBERG;
pub use error::JARVIS_JUDICE_NINKE;
pub use error::ATKINSON;
pub use error::BURKES;
pub use error::STUCKI;
pub use error::SIERRA;
pub use error::SIERRA_TWO_ROW;
pub use error::SIERRA_LITE;

Modules

bayer
Contains logic for Ordered / Bayer dithering.
error
Contains all the dithering logic for the error propagation based algorithms.