Module error

Module error 

Contains all the dithering logic for the error propagation based algorithms.

Structs

Base
Every ErrorPropagator starts with a state of Base.
ErrorPropagator
This struct defines an error propagation algorithm. For existing algorithms, the constants should be used instead.
WithPalette
Once an ErrorPropagator acquires a colour palette, it enters the WithPalette state.

Constants

ATKINSON
The Atkinson error propagation method.
BURKES
The Burkes error propagation method.
FLOYD_STEINBERG
The Floyd-Steinberg error propagation method.
JARVIS_JUDICE_NINKE
The Jarvis-Judice-Ninke error propagation method.
SIERRA
The Sierra error propagation method.
SIERRA_LITE
The Sierra (lite) error propagation method. A variant of Sierra.
SIERRA_TWO_ROW
The Sierra (Two Row) error propagation method. A variant of Sierra.
STUCKI
The Stucki error propagation method.

Traits

PropagatorState
Note: This trait is sealed and should not be used externally.