IntoGradient

Trait IntoGradient 

pub trait IntoGradient:
    IntoGradientHsl
    + IntoGradientLch
    + IntoGradientOklch {
    // Provided method
    fn build_gradient(self, shades: u16, method: GradientMethod) -> Vec<Self> { ... }
}
Defines a colour that can generate a gradient through all supported gradient methods.

Should be auto-implemented by having a colour satisfy the trait bounds.

Provided Methods

fn build_gradient(self, shades: u16, method: GradientMethod) -> Vec<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors