pub trait Affectable<T, F: Effect<T>> {
// Required method
fn apply(self, effect: &F) -> Self;
}Expand description
Defines something that can be affected.
This is auto-implemented for any T and F where F
is an effect that can be applied on T.
As a result it should almost never be implemented directly, like Into<T> in the
standard library.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".